@@ -15,6 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <QtGlobal>
+
 #include "longtextmessagebox.h"
 
 #include "addactivityform.h"
@@ -28,7 +30,11 @@
 
 #include <QDialog>
 
+#if QT_VERSION >= 0x050000
+#include <QtWidgets>
+#else
 #include <QtGui>
+#endif
 
 #include <QList>
 
@@ -861,8 +867,8 @@ void AddActivityForm::help()
 
 	s+="\n\n";
 	
-	s+=tr("If you select a number of min days above 1, you will get the possibility "
-	 "to add a second constraint min days between activities, with min days 1 and a percentage of your choice. Just click "
+	s+=tr("If you select a number of min days above 1 (say this number is n), you will get the possibility "
+	 "to add a second constraint min days between activities, with min days = n-1 and a percentage of your choice. Just click "
 	 "Add activities");
 	
 	//show the message in a dialog
