@@ -28,9 +28,13 @@ class AdvancedLockUnlockForm: public QObject{
 public:
 	static void lockAll(QWidget* parent);
 	static void unlockAll(QWidget* parent);
+
+	static void unlockAllWithoutTimetable(QWidget* parent);
 	
 	static void lockDay(QWidget* parent);
 	static void unlockDay(QWidget* parent);
+
+	static void unlockDayWithoutTimetable(QWidget* parent);
 	
 	static void lockEndStudentsDay(QWidget* parent);
 	static void unlockEndStudentsDay(QWidget* parent);
