@@ -478,6 +478,7 @@ void ModifyActivityForm::ok()
 	int total_number_of_students=0;
 	for(QStringList::Iterator it=students_names.begin(); it!=students_names.end(); it++){
 		StudentsSet* ss=gt.rules.searchStudentsSet(*it);
+		assert(ss!=NULL);
 		total_number_of_students+=ss->numberOfStudents;
 	}
 
@@ -533,8 +534,8 @@ void ModifyActivityForm::help()
 	s+="\n\n";
 	s+=tr("'Students' (the text near the spin box), means 'Number of students (-1 for automatic)'");
 	s+="\n";
-	s+=tr("'Split' means 'Is split into ... activities per week. This value cannot be changed."
-	 " If you need to modify it, please remove the corresponding activities and add a new split activity.'");
+	s+=tr("'Split' means 'Is split into ... activities per week'. This value cannot be changed."
+	 " If you need to modify it, please remove the corresponding activities and add a new split activity.");
 	s+="\n";
 	s+=tr("The 'Duration' spin box and the 'Active' check box refer to each component of current activity, you can change "
 	 "them for each component, separately, by selecting the corresponding tab in the tab widget.");
