@@ -17,41 +17,32 @@
 
 #include <QMessageBox>
 
-#include <cstdio>
-
 #include "modifyconstraintteachermaxbuildingchangesperdayform.h"
 #include "spaceconstraint.h"
 
-ModifyConstraintTeacherMaxBuildingChangesPerDayForm::ModifyConstraintTeacherMaxBuildingChangesPerDayForm(ConstraintTeacherMaxBuildingChangesPerDay* ctr)
+ModifyConstraintTeacherMaxBuildingChangesPerDayForm::ModifyConstraintTeacherMaxBuildingChangesPerDayForm(QWidget* parent, ConstraintTeacherMaxBuildingChangesPerDay* ctr): QDialog(parent)
 {
-    setupUi(this);
+	setupUi(this);
 
-//    connect(weightLineEdit, SIGNAL(textChanged(QString)), this /*ModifyConstraintTeacherMaxBuildingChangesPerDayForm_template*/, SLOT(constraintChanged()));
-    connect(okPushButton, SIGNAL(clicked()), this /*ModifyConstraintTeacherMaxBuildingChangesPerDayForm_template*/, SLOT(ok()));
-    connect(cancelPushButton, SIGNAL(clicked()), this /*ModifyConstraintTeacherMaxBuildingChangesPerDayForm_template*/, SLOT(cancel()));
-//    connect(teachersComboBox, SIGNAL(activated(QString)), this /*ModifyConstraintTeacherMaxBuildingChangesPerDayForm_template*/, SLOT(constraintChanged()));
-//    connect(maxChangesSpinBox, SIGNAL(valueChanged(int)), this /*ModifyConstraintTeacherMaxBuildingChangesPerDayForm_template*/, SLOT(constraintChanged()));
+	okPushButton->setDefault(true);
 
+	connect(okPushButton, SIGNAL(clicked()), this, SLOT(ok()));
+	connect(cancelPushButton, SIGNAL(clicked()), this, SLOT(cancel()));
 
-	//setWindowFlags(Qt::Window);
-	//setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
-	/*QDesktopWidget* desktop=QApplication::desktop();
-	int xx=desktop->width()/2 - frameGeometry().width()/2;
-	int yy=desktop->height()/2 - frameGeometry().height()/2;
-	move(xx, yy);*/
 	centerWidgetOnScreen(this);
+	restoreFETDialogGeometry(this);
 
 	QSize tmp1=teachersComboBox->minimumSizeHint();
 	Q_UNUSED(tmp1);
 		
 	this->_ctr=ctr;
 	
-	weightLineEdit->setText(QString::number(ctr->weightPercentage));
+	weightLineEdit->setText(CustomFETString::number(ctr->weightPercentage));
 	
 	updateTeachersComboBox();
 
-	maxChangesSpinBox->setMinValue(0);
-	maxChangesSpinBox->setMaxValue(gt.rules.nHoursPerDay);
+	maxChangesSpinBox->setMinimum(0);
+	maxChangesSpinBox->setMaximum(gt.rules.nHoursPerDay);
 	maxChangesSpinBox->setValue(ctr->maxBuildingChangesPerDay);	
 		
 	constraintChanged();
@@ -59,6 +50,7 @@ ModifyConstraintTeacherMaxBuildingChangesPerDayForm::ModifyConstraintTeacherMaxB
 
 ModifyConstraintTeacherMaxBuildingChangesPerDayForm::~ModifyConstraintTeacherMaxBuildingChangesPerDayForm()
 {
+	saveFETDialogGeometry(this);
 }
 
 void ModifyConstraintTeacherMaxBuildingChangesPerDayForm::updateTeachersComboBox()
@@ -67,44 +59,25 @@ void ModifyConstraintTeacherMaxBuildingChangesPerDayForm::updateTeachersComboBox
 	int i=0, j=-1;
 	for(int k=0; k<gt.rules.teachersList.size(); k++, i++){
 		Teacher* tch=gt.rules.teachersList[k];
-		teachersComboBox->insertItem(tch->name);
+		teachersComboBox->addItem(tch->name);
 		if(tch->name==this->_ctr->teacherName)
 			j=i;
 	}
 	assert(j>=0);
-	teachersComboBox->setCurrentItem(j);
+	teachersComboBox->setCurrentIndex(j);
 
 	constraintChanged();
 }
 
 void ModifyConstraintTeacherMaxBuildingChangesPerDayForm::constraintChanged()
-{/*
-	QString s;
-	s+=tr("Current constraint:");
-	s+="\n";
-
-	double weight;
-	QString tmp=weightLineEdit->text();
-	sscanf(tmp, "%lf", &weight);
-	s+=tr(QString("Weight (percentage)=%1\%").arg(weight));
-	s+="\n";
-
-	s+=tr("Teacher max building changes per day");
-	s+="\n";
-	s+=tr("Teacher=%1").arg(teachersComboBox->currentText());
-	s+="\n";
-	
-	s+=tr("Max building changes per day=%1").arg(maxChangesSpinBox->value());
-	s+="\n";
-
-	currentConstraintTextEdit->setText(s);*/
+{
 }
 
 void ModifyConstraintTeacherMaxBuildingChangesPerDayForm::ok()
 {
 	double weight;
 	QString tmp=weightLineEdit->text();
-	sscanf(tmp, "%lf", &weight);
+	weight_sscanf(tmp, "%lf", &weight);
 	if(weight<100.0 || weight>100.0){
 		QMessageBox::warning(this, tr("FET information"),
 			tr("Invalid weight (percentage). It has to be 100"));
@@ -124,6 +97,7 @@ void ModifyConstraintTeacherMaxBuildingChangesPerDayForm::ok()
 	this->_ctr->maxBuildingChangesPerDay=maxChangesSpinBox->value();
 
 	gt.rules.internalStructureComputed=false;
+	setRulesModifiedAndOtherThings(&gt.rules);
 	
 	this->close();
 }
