@@ -15,6 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <QtGlobal>
+
 #include "tablewidgetupdatebug.h"
 
 #include "longtextmessagebox.h"
@@ -82,13 +84,10 @@ TimetableViewStudentsForm::TimetableViewStudentsForm(QWidget* parent): QDialog(p
 
 	//columnResizeModeInitialized=false;
 
-	QList<int> tmpList2;
-	tmpList2<<10000<<2500;
-	verticalStudentsTableDetailsSplitter->setSizes(tmpList2);
-	
-	QList<int> tmpList3;
-	tmpList3<<3000<<10000;
-	horizontalSplitter->setSizes(tmpList3);
+	verticalStudentsTableDetailsSplitter->setStretchFactor(0, 4);
+	verticalStudentsTableDetailsSplitter->setStretchFactor(1, 1);
+	horizontalSplitter->setStretchFactor(0, 3);
+	horizontalSplitter->setStretchFactor(1, 10);
 	
 	studentsTimetableTable->setSelectionMode(QAbstractItemView::ExtendedSelection);
 	
@@ -177,7 +176,11 @@ TimetableViewStudentsForm::TimetableViewStudentsForm(QWidget* parent): QDialog(p
 	//if(!columnResizeModeInitialized){
 	studentsTimetableTable->horizontalHeader()->setMinimumSectionSize(studentsTimetableTable->horizontalHeader()->defaultSectionSize());
 	//	columnResizeModeInitialized=true;
+#if QT_VERSION >= 0x050000
+	studentsTimetableTable->horizontalHeader()->setSectionResizeMode(QHeaderView::Stretch);
+#else
 	studentsTimetableTable->horizontalHeader()->setResizeMode(QHeaderView::Stretch);
+#endif
 	//}
 	///////////////
 	
@@ -361,8 +364,13 @@ void TimetableViewStudentsForm::updateStudentsTimetableTable(){
 				Activity* act=&gt.rules.internalActivitiesList[ai];
 				assert(act!=NULL);
 				
-				QString ats=act->activityTagsNames.join(", ");
-				s+=act->subjectName +" "+ ats;
+				if(TIMETABLE_HTML_PRINT_ACTIVITY_TAGS){
+					QString ats=act->activityTagsNames.join(", ");
+					s+=act->subjectName +" "+ ats;
+				}
+				else{
+					s+=act->subjectName;
+				}
 				
 				if(act->teachersNames.count()>0){
 					s+="\n";
@@ -656,34 +664,33 @@ void TimetableViewStudentsForm::lock(bool lockTime, bool lockSpace)
 							QList<TimeConstraint*> tmptc;
 							tmptc.clear();
 							int count=0;
-							foreach(TimeConstraint* tc, gt.rules.timeConstraintsList){
-								if(tc->type==CONSTRAINT_ACTIVITY_PREFERRED_STARTING_TIME){
-									ConstraintActivityPreferredStartingTime* c=(ConstraintActivityPreferredStartingTime*) tc;
-									if(c->activityId==act->id && c->weightPercentage==100.0 && c->active && c->day>=0 && c->hour>=0){
-										count++;
-										if(c->permanentlyLocked){
-											if(idsOfLockedTime.contains(c->activityId) || !idsOfPermanentlyLockedTime.contains(c->activityId)){
-												QMessageBox::warning(this, tr("FET warning"), tr("Small problem detected")
-												 +"\n\n"+tr("A possible problem might be that you have 2 or more constraints of type activity preferred starting time with weight 100% related to activity id %1, please leave only one of them").arg(act->id)
-												 +"\n\n"+tr("A possible problem might be synchronization - so maybe try to close the timetable view dialog and open it again")
-												 +"\n\n"+tr("Please report possible bug")
-												);
-											}
-											else{
-												s+=tr("Constraint %1 will not be removed, because it is permanently locked. If you want to unlock it you must go to the constraints menu.").arg("\n"+c->getDetailedDescription(gt.rules)+"\n");
-											}
+
+							foreach(ConstraintActivityPreferredStartingTime* c, gt.rules.apstHash.value(act->id, QSet<ConstraintActivityPreferredStartingTime*>())){
+								assert(c->activityId==act->id);
+								if(c->activityId==act->id && c->weightPercentage==100.0 && c->active && c->day>=0 && c->hour>=0){
+									count++;
+									if(c->permanentlyLocked){
+										if(idsOfLockedTime.contains(c->activityId) || !idsOfPermanentlyLockedTime.contains(c->activityId)){
+											QMessageBox::warning(this, tr("FET warning"), tr("Small problem detected")
+											  +"\n\n"+tr("A possible problem might be that you have 2 or more constraints of type activity preferred starting time with weight 100% related to activity id %1, please leave only one of them").arg(act->id)
+											  +"\n\n"+tr("A possible problem might be synchronization - so maybe try to close the timetable view dialog and open it again")
+											  +"\n\n"+tr("Please report possible bug")
+											);
 										}
 										else{
-											if(!idsOfLockedTime.contains(c->activityId) || idsOfPermanentlyLockedTime.contains(c->activityId)){
-												QMessageBox::warning(this, tr("FET warning"), tr("Small problem detected")
-												 +"\n\n"+tr("A possible problem might be that you have 2 or more constraints of type activity preferred starting time with weight 100% related to activity id %1, please leave only one of them").arg(act->id)
-												 +"\n\n"+tr("A possible problem might be synchronization - so maybe try to close the timetable view dialog and open it again")
-												 +"\n\n"+tr("Please report possible bug")
-												);
-											}
-											else{
-												tmptc.append(tc);
-											}
+											s+=tr("Constraint %1 will not be removed, because it is permanently locked. If you want to unlock it you must go to the constraints menu.").arg("\n"+c->getDetailedDescription(gt.rules)+"\n");
+										}
+									}
+									else{
+										if(!idsOfLockedTime.contains(c->activityId) || idsOfPermanentlyLockedTime.contains(c->activityId)){
+											QMessageBox::warning(this, tr("FET warning"), tr("Small problem detected")
+											  +"\n\n"+tr("A possible problem might be that you have 2 or more constraints of type activity preferred starting time with weight 100% related to activity id %1, please leave only one of them").arg(act->id)
+											  +"\n\n"+tr("A possible problem might be synchronization - so maybe try to close the timetable view dialog and open it again")
+											  +"\n\n"+tr("Please report possible bug")
+											);
+										}
+										else{
+											tmptc.append((TimeConstraint*)c);
 										}
 									}
 								}
@@ -704,12 +711,9 @@ void TimetableViewStudentsForm::lock(bool lockTime, bool lockSpace)
 						
 						if(report){
 							int k;
-							if(t)
-								k=QMessageBox::information(this, tr("FET information"), s,
-							 	 tr("Skip information"), tr("See next"), QString(), 1, 0 );
-							else
-								k=QMessageBox::information(this, tr("FET information"), s,
-							 	 tr("Skip information"), tr("See next"), QString(), 1, 0 );
+							k=QMessageBox::information(this, tr("FET information"), s,
+							 tr("Skip information"), tr("See next"), QString(), 1, 0 );
+
 		 					if(k==0)
 								report=false;
 						}
@@ -733,34 +737,33 @@ void TimetableViewStudentsForm::lock(bool lockTime, bool lockSpace)
 							QList<SpaceConstraint*> tmpsc;
 							tmpsc.clear();
 							int count=0;
-							foreach(SpaceConstraint* sc, gt.rules.spaceConstraintsList){
-								if(sc->type==CONSTRAINT_ACTIVITY_PREFERRED_ROOM){
-									ConstraintActivityPreferredRoom* c=(ConstraintActivityPreferredRoom*) sc;
-									if(c->activityId==act->id && c->weightPercentage==100.0 && c->active){
-										count++;
-										if(c->permanentlyLocked){
-											if(idsOfLockedSpace.contains(c->activityId) || !idsOfPermanentlyLockedSpace.contains(c->activityId)){
-												QMessageBox::warning(this, tr("FET warning"), tr("Small problem detected")
-												 +"\n\n"+tr("A possible problem might be that you have 2 or more constraints of type activity preferred room with weight 100% related to activity id %1, please leave only one of them").arg(act->id)
-												 +"\n\n"+tr("A possible problem might be synchronization - so maybe try to close the timetable view dialog and open it again")
-												 +"\n\n"+tr("Please report possible bug")
-												);
-											}
-											else{
-												s+=tr("Constraint %1 will not be removed, because it is permanently locked. If you want to unlock it you must go to the constraints menu.").arg("\n"+c->getDetailedDescription(gt.rules)+"\n");
-											}
+
+							foreach(ConstraintActivityPreferredRoom* c, gt.rules.aprHash.value(act->id, QSet<ConstraintActivityPreferredRoom*>())){
+								assert(c->activityId==act->id);
+								if(c->activityId==act->id && c->weightPercentage==100.0 && c->active){
+									count++;
+									if(c->permanentlyLocked){
+										if(idsOfLockedSpace.contains(c->activityId) || !idsOfPermanentlyLockedSpace.contains(c->activityId)){
+											QMessageBox::warning(this, tr("FET warning"), tr("Small problem detected")
+											  +"\n\n"+tr("A possible problem might be that you have 2 or more constraints of type activity preferred room with weight 100% related to activity id %1, please leave only one of them").arg(act->id)
+											  +"\n\n"+tr("A possible problem might be synchronization - so maybe try to close the timetable view dialog and open it again")
+											  +"\n\n"+tr("Please report possible bug")
+											);
 										}
 										else{
-											if(!idsOfLockedSpace.contains(c->activityId) || idsOfPermanentlyLockedSpace.contains(c->activityId)){
-												QMessageBox::warning(this, tr("FET warning"), tr("Small problem detected")
-												 +"\n\n"+tr("A possible problem might be that you have 2 or more constraints of type activity preferred room with weight 100% related to activity id %1, please leave only one of them").arg(act->id)
-												 +"\n\n"+tr("A possible problem might be synchronization - so maybe try to close the timetable view dialog and open it again")
-												 +"\n\n"+tr("Please report possible bug")
-												);
-											}
-											else{
-												tmpsc.append(sc);
-											}
+											s+=tr("Constraint %1 will not be removed, because it is permanently locked. If you want to unlock it you must go to the constraints menu.").arg("\n"+c->getDetailedDescription(gt.rules)+"\n");
+										}
+									}
+									else{
+										if(!idsOfLockedSpace.contains(c->activityId) || idsOfPermanentlyLockedSpace.contains(c->activityId)){
+											QMessageBox::warning(this, tr("FET warning"), tr("Small problem detected")
+											  +"\n\n"+tr("A possible problem might be that you have 2 or more constraints of type activity preferred room with weight 100% related to activity id %1, please leave only one of them").arg(act->id)
+											  +"\n\n"+tr("A possible problem might be synchronization - so maybe try to close the timetable view dialog and open it again")
+											  +"\n\n"+tr("Please report possible bug")
+											);
+										}
+										else{
+											tmpsc.append((SpaceConstraint*)c);
 										}
 									}
 								}
@@ -781,12 +784,8 @@ void TimetableViewStudentsForm::lock(bool lockTime, bool lockSpace)
 						
 						if(report){
 							int k;
-							if(t)
-								k=QMessageBox::information(this, tr("FET information"), s,
-							 	 tr("Skip information"), tr("See next"), QString(), 1, 0 );
-							else
-								k=QMessageBox::information(this, tr("FET information"), s,
-							 	 tr("Skip information"), tr("See next"), QString(), 1, 0 );
+							k=QMessageBox::information(this, tr("FET information"), s,
+							 tr("Skip information"), tr("See next"), QString(), 1, 0 );
 							
 		 					if(k==0)
 								report=false;
